<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AppearancePage</name>
    <message>
        <location filename="../appearancepage.ui" line="22"/>
        <source>Style:</source>
        <translation>风格：</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="107"/>
        <source>Preview</source>
        <translation>预览</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="117"/>
        <source>Active palette</source>
        <translation>激活状态的调色板</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="122"/>
        <source>Inactive palette</source>
        <translation>非激活状态的调色板</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="127"/>
        <source>Disabled palette</source>
        <translation>失效状态的调色板</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="84"/>
        <location filename="../appearancepage.cpp" line="370"/>
        <source>Default</source>
        <translation>缺省</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="42"/>
        <source>Color scheme:</source>
        <translation>颜色方案：</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="82"/>
        <source>Standard dialogs:</source>
        <translation>标准对话框：</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="71"/>
        <source>Create</source>
        <translation>创建</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="72"/>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="73"/>
        <source>Create a Copy</source>
        <translation>创建副本</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="74"/>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="76"/>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="167"/>
        <location filename="../appearancepage.cpp" line="241"/>
        <location filename="../appearancepage.cpp" line="280"/>
        <source>Enter Color Scheme Name</source>
        <translation>输入颜色方案名称</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="167"/>
        <location filename="../appearancepage.cpp" line="241"/>
        <location filename="../appearancepage.cpp" line="280"/>
        <source>File name:</source>
        <translation>文件名：</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="176"/>
        <location filename="../appearancepage.cpp" line="252"/>
        <location filename="../appearancepage.cpp" line="260"/>
        <location filename="../appearancepage.cpp" line="290"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="176"/>
        <location filename="../appearancepage.cpp" line="252"/>
        <location filename="../appearancepage.cpp" line="290"/>
        <source>The color scheme &quot;%1&quot; already exists</source>
        <translation>颜色方案 &quot;%1&quot; 已经存在</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="194"/>
        <location filename="../appearancepage.cpp" line="217"/>
        <location filename="../appearancepage.cpp" line="275"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="194"/>
        <location filename="../appearancepage.cpp" line="217"/>
        <location filename="../appearancepage.cpp" line="275"/>
        <source>The color scheme &quot;%1&quot; is read only</source>
        <translation>颜色方案 &quot;%1&quot; 是只读状态</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="222"/>
        <source>Confirm Remove</source>
        <translation>确认移除</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="223"/>
        <source>Are you sure you want to remove color scheme &quot;%1&quot;?</source>
        <translation>您确定要移除颜色方案 &quot;%1&quot; 吗？</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="243"/>
        <source>%1 (copy)</source>
        <translation>%1(拷贝)</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="260"/>
        <source>Unable to copy file</source>
        <translation>无法复制文件</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="371"/>
        <source>Style&apos;s colors</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FontConfigDialog</name>
    <message>
        <location filename="../fontconfigdialog.ui" line="14"/>
        <location filename="../fontconfigdialog.cpp" line="74"/>
        <source>Font Configuration</source>
        <translation>字体配置</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="29"/>
        <source>Disable automatic hinting for bold fonts</source>
        <translation>禁用粗体自动微调</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="36"/>
        <source>LCD filter:</source>
        <translation>LCD 过滤器：</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="43"/>
        <source>Automatic hinting</source>
        <translation>自动微调</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="50"/>
        <source>Hinting</source>
        <translation>微调</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="67"/>
        <source>Font resolution:</source>
        <translation>字体分辨率</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="110"/>
        <source> dpi</source>
        <translation>dpi</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="83"/>
        <source>Subpixel geometry:</source>
        <translation>子像素排列：</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="90"/>
        <source>Antialiasing</source>
        <translation>抗锯齿</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="97"/>
        <source>Hinting style:</source>
        <translation>微调风格</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="43"/>
        <location filename="../fontconfigdialog.cpp" line="48"/>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="44"/>
        <source>Slight</source>
        <translation>轻微</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="45"/>
        <source>Medium</source>
        <translation>中等</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="46"/>
        <source>Full</source>
        <translation>全部</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="75"/>
        <source>&lt;i&gt;%1&lt;/i&gt; already exists. Do you want to replace it?</source>
        <translation>&lt;i&gt;%1&lt;/i&gt; 已经存在。您想要取代它吗？</translation>
    </message>
</context>
<context>
    <name>FontsPage</name>
    <message>
        <location filename="../fontspage.ui" line="47"/>
        <location filename="../fontspage.ui" line="67"/>
        <location filename="../fontspage.ui" line="86"/>
        <location filename="../fontspage.ui" line="93"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="60"/>
        <source>General:</source>
        <translation>一般：</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="100"/>
        <source>Fixed width:</source>
        <translation>固定宽度：</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="125"/>
        <source>Create  fonts.conf</source>
        <translation>创建 fonts.conf</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="132"/>
        <source>Remove fonts.conf</source>
        <translation>移除 fonts.conf</translation>
    </message>
    <message>
        <location filename="../fontspage.cpp" line="110"/>
        <source>Remove Font Configuration</source>
        <translation>移除字体配置</translation>
    </message>
    <message>
        <location filename="../fontspage.cpp" line="111"/>
        <source>Are you sure you want to delete &lt;i&gt;%1&lt;/i&gt;?</source>
        <translation>您确定要删除&lt;i&gt;%1&lt;/i&gt;吗？</translation>
    </message>
</context>
<context>
    <name>InterfacePage</name>
    <message>
        <location filename="../interfacepage.ui" line="35"/>
        <source>Double click interval:</source>
        <translation>双击间隔：</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="42"/>
        <source>Cursor flash time:</source>
        <translation>光标闪烁间隔：</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="49"/>
        <source>ComboBox effect:</source>
        <translation>下拉框效果：</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="56"/>
        <source>ToolTip effect:</source>
        <translation>提示效果：</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="63"/>
        <source>ToolBox effect:</source>
        <translation>工具箱效果：</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="70"/>
        <location filename="../interfacepage.ui" line="80"/>
        <source> ms</source>
        <translation>毫秒</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="94"/>
        <location filename="../interfacepage.ui" line="111"/>
        <location filename="../interfacepage.ui" line="133"/>
        <location filename="../interfacepage.ui" line="157"/>
        <source>Disable</source>
        <translation>禁用</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="99"/>
        <location filename="../interfacepage.ui" line="116"/>
        <location filename="../interfacepage.ui" line="138"/>
        <location filename="../interfacepage.ui" line="162"/>
        <source>Animate</source>
        <translation>动画</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="121"/>
        <location filename="../interfacepage.ui" line="167"/>
        <source>Fade</source>
        <translation>阴影</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="146"/>
        <source>Menu effect:</source>
        <translation>菜单效果：</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="175"/>
        <source>Enable gui effects</source>
        <translation>启用GUI效果</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="182"/>
        <source>Dialog buttons layout:</source>
        <translation>对话框按钮布局：</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="192"/>
        <source>Keyboard scheme:</source>
        <translation>键盘方案：</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="202"/>
        <source>Menus have icons</source>
        <translation>有图标的菜单</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="209"/>
        <source>Dialog buttons have icons</source>
        <translation>有图标的对话框按钮</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="219"/>
        <source>Activate item on single-click</source>
        <translation>单击激活项目</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="229"/>
        <source>Toolbar button style:</source>
        <translation>工具栏按钮风格：</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="239"/>
        <source>Mouse wheel scroll lines:</source>
        <translation>鼠标滚轮滚动行数：</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="256"/>
        <source>Show shortcut underlines</source>
        <translation>显示快捷方式下划线</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="266"/>
        <source>Show shortcuts in context menus</source>
        <translation>在右键菜单显示快捷方式</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="55"/>
        <source>Only display the icon</source>
        <translation>仅显示图标</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="56"/>
        <source>Only display the text</source>
        <translation>仅显示文本</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="57"/>
        <source>The text appears beside the icon</source>
        <translation>文本位于图标旁</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="58"/>
        <source>The text appears under the icon</source>
        <translation>文本位于图标下方</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="59"/>
        <source>Follow the application style</source>
        <translation>跟随应用程序风格</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Qt6 Configuration Tool</source>
        <translation>Qt6 配置工具</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="54"/>
        <source>The application is not configured correctly.</source>
        <translation>未正确配置应用程序。</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="61"/>
        <source>Information</source>
        <translation>信息</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="68"/>
        <source>Hide</source>
        <translation>隐藏</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="51"/>
        <source>Appearance</source>
        <translation>外观</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="52"/>
        <source>Fonts</source>
        <translation>字体</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="53"/>
        <source>Icon Theme</source>
        <translation>图标主题</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="54"/>
        <source>Interface</source>
        <translation>界面</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="56"/>
        <source>Style Sheets</source>
        <translation>样式表</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="58"/>
        <source>Troubleshooting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="65"/>
        <source>Version: %1</source>
        <translation>版本：%1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="111"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="120"/>
        <source>Please remove the &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; environment variable (current value: &lt;b&gt;%1&lt;/b&gt;).</source>
        <translation>请移除&lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt;环境变量(当前值：&lt;b&gt;%1&lt;/b&gt;)。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set (required values: &lt;b&gt;qt6ct&lt;/b&gt; or &lt;b&gt;qt5ct&lt;/b&gt;).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="131"/>
        <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set correctly (current value: &lt;b&gt;%1&lt;/b&gt;, required values: &lt;b&gt;qt6ct&lt;/b&gt; or &lt;b&gt;qt5ct&lt;/b&gt;).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="138"/>
        <source>Unable to find &lt;b&gt;libqt6ct-style.so&lt;/b&gt;</source>
        <translation>无法找到&lt;b&gt;libqt6ct-style.so&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="144"/>
        <source>The &lt;b&gt;%1&lt;/b&gt; plugin is compiled against incompatible Qt version (%2).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PaletteEditDialog</name>
    <message>
        <location filename="../paletteeditdialog.ui" line="14"/>
        <source>Palette Editor</source>
        <translation>调色板编辑器</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="79"/>
        <source>Reset palette</source>
        <translation>重置调色板</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="29"/>
        <source>Build inactive palette</source>
        <translation>构建非激活的调色板</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="36"/>
        <source>Build disabled palette</source>
        <translation>构建禁用状态调色板</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="48"/>
        <source>Active</source>
        <translation>激活</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="48"/>
        <source>Inactive</source>
        <translation>非激活</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="48"/>
        <source>Disabled</source>
        <translation>已禁用</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Dark</source>
        <translation>暗</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Window text</source>
        <translation>窗口文字</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Button background</source>
        <translation>按钮背景</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Bright</source>
        <translation>亮</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Less bright</source>
        <translation>较不亮</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Less dark</source>
        <translation>较不暗</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Window</source>
        <translation>窗口</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Shadow</source>
        <translation>阴影</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Bright text</source>
        <translation>亮文字</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Button text</source>
        <translation>按钮文字</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Normal text</source>
        <translation>普通文字</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Normal background</source>
        <translation>普通背景</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Highlight</source>
        <translation>高亮</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Highlighted text</source>
        <translation>高亮文字</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Visited link</source>
        <translation>已访问的链接</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Default</source>
        <translation>缺省</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Tooltip background</source>
        <translation>提示语背景</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Tooltip text</source>
        <translation>提示语文字</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Link</source>
        <translation>链接</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Alternate background</source>
        <translation>备用背景</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Placeholder text</source>
        <translation>占位符文本</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="97"/>
        <source>Accent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="110"/>
        <source>Select Color</source>
        <translation>选择颜色</translation>
    </message>
</context>
<context>
    <name>PreviewForm</name>
    <message>
        <location filename="../previewform.ui" line="14"/>
        <source>Preview Window</source>
        <translation>预览窗口</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="27"/>
        <source>Tab 1</source>
        <translation>页面1</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="36"/>
        <source>PushButton</source>
        <translation>按钮</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="65"/>
        <source>Tab 2</source>
        <translation>页面2</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="74"/>
        <source>RadioButton</source>
        <translation>单选按钮</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="84"/>
        <source>CheckBox</source>
        <translation>复选框</translation>
    </message>
</context>
<context>
    <name>QSSEditorDialog</name>
    <message>
        <location filename="../qsseditordialog.cpp" line="46"/>
        <source>%1 - Style Sheet Editor</source>
        <translation>%1 - 样式表编辑器</translation>
    </message>
    <message>
        <location filename="../qsseditordialog.ui" line="14"/>
        <source>Style Sheet Editor</source>
        <translation>样式表编辑器</translation>
    </message>
</context>
<context>
    <name>QSSPage</name>
    <message>
        <location filename="../qsspage.ui" line="23"/>
        <source>Create</source>
        <translation>新建</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="66"/>
        <location filename="../qsspage.cpp" line="51"/>
        <location filename="../qsspage.cpp" line="86"/>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="76"/>
        <location filename="../qsspage.cpp" line="53"/>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="33"/>
        <location filename="../qsspage.cpp" line="55"/>
        <source>Remove</source>
        <translation>删除</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="52"/>
        <source>Create a Copy</source>
        <translation>创建副本</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="91"/>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="105"/>
        <location filename="../qsspage.cpp" line="250"/>
        <source>File name:</source>
        <translation>文件名：</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="105"/>
        <location filename="../qsspage.cpp" line="250"/>
        <source>Enter Style Sheet Name</source>
        <translation>输入样式表名称</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="116"/>
        <location filename="../qsspage.cpp" line="217"/>
        <location filename="../qsspage.cpp" line="225"/>
        <location filename="../qsspage.cpp" line="262"/>
        <location filename="../qsspage.cpp" line="270"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="116"/>
        <source>The file &quot;%1&quot; already exists</source>
        <translation>文件 “%1”  已经存在</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="150"/>
        <source>Confirm Remove</source>
        <translation>确定删除</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="151"/>
        <source>Are you sure you want to remove style sheet &quot;%1&quot;?</source>
        <translation>您确定要移除样式表 &quot;%1&quot; 吗？</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="207"/>
        <source>Rename Style Sheet</source>
        <translation>重命名样式表</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="207"/>
        <source>Style sheet name:</source>
        <translation>样式表名称：</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="217"/>
        <location filename="../qsspage.cpp" line="262"/>
        <source>The style sheet &quot;%1&quot; already exists</source>
        <translation>样式表 “%1” 已经存在</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="225"/>
        <source>Unable to rename file</source>
        <translation>无法重命名文件</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="252"/>
        <source>%1 (copy).qss</source>
        <translation>%1 (副本).qss</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="270"/>
        <source>Unable to copy file</source>
        <translation>无法复制文件</translation>
    </message>
</context>
<context>
    <name>TroubleshootingPage</name>
    <message>
        <location filename="../troubleshootingpage.ui" line="20"/>
        <source>Ignored applications:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="29"/>
        <source>Add...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="40"/>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="73"/>
        <source>Do not apply any styles and color schemes for the listed applications.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="82"/>
        <source>Make top-level widgets use pure raster surfaces, and do not support non-native GL-based child widgets.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="85"/>
        <source>Force raster surface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.cpp" line="63"/>
        <source>Select Application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.cpp" line="63"/>
        <source>Executable files (*)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
